@@ -1,4 +1,7 @@
-library(rrcov)
+## VT::15.09.2013 - this will render the output independent
+##  from the version of the package
+suppressPackageStartupMessages(library(rrcov))
+
 dodata <- function(method) {
 
     options(digits = 5)
